# pycrackwatch

A simple wrapper for the crackwatch API (https://crackwatch.com/api)


## Installing

To install pycrackwatch just run

```
pip install pycrackwatch
```

## Testing

The tests are located inside the tests folder, to run them with pytest use

```
py.test tests
```
